@@ -122,9 +122,9 @@ getaline_r (char **line, int *size, FILE * f, struct thread_mem *thread_mem)
 
   if (*line == NULL)
     {
-      p = pxmalloc (*size, thread_mem);	
-      if( p == NULL )/* for mutex, we shouldn't exit here? */
-              return PROXYKNIFE_THREAD_EXIT;
+      p = pxmalloc (*size, thread_mem);
+      if (p == NULL)		/* for mutex, we shouldn't exit here? */
+	return PROXYKNIFE_THREAD_EXIT;
     }
   else
     {
@@ -138,7 +138,8 @@ getaline_r (char **line, int *size, FILE * f, struct thread_mem *thread_mem)
 	{
 	  *size = offset + linelen + D;
 	  q = pxrealloc (p, *size, thread_mem);
-      if( q == NULL ) return PROXYKNIFE_THREAD_EXIT;
+	  if (q == NULL)
+	    return PROXYKNIFE_THREAD_EXIT;
 	  p = q;
 	}
 
