@@ -84,6 +84,124 @@ http_build_auth ()
   /* printf ("%s\n", header_auth); */
 }
 
+/* Connect to req via a HTTP proxy.
+ * The HTTP proxy should support CONNECT.
+ * 
+ * The format of req is "host:port". 
+ * Return value:
+ * 0: success!
+ * -1: failure.
+ * */
+int
+CONVIAHTTP_MAIN (int sockfd, char *host, char *port)
+{
+  int ret, len, offset;
+  char *p;
+
+  /* connect to myhost:myport */
+  ret =
+    connect (sockfd, (struct sockaddr *) &(my.myaddr),
+	     sizeof (struct sockaddr));
+  if (ret == -1)
+    {
+      perror ("CONVIAHTTP:connect:Connect to myaddr");
+      return -1;
+    }
+
+  /* build request */
+  if (my.mytype == HTTP_CONNECT_AUTH)
+    {
+      len =
+	strlen ("CONNECT  HTTP/1.0") + strlen (host) + strlen (":") +
+	strlen (port) + 2 + strlen (user_agent) + 2 + strlen (NOCACHE) + 2 +
+	strlen ((const char *) my.header_auth) + 2 + 2;
+
+      /* my.buffer = NULL before this call */
+      my.buffer = xmalloc (len + 1);
+      if (my.buffer == NULL)
+	{
+	  xexit (EXIT_FAILURE);
+	}
+      snprintf (my.buffer, len + 1,
+		"CONNECT %s:%s HTTP/1.0\r\n"
+		"%s\r\n"
+		"%s\r\n"
+		"%s\r\n" "\r\n", host, port, user_agent,
+		NOCACHE, my.header_auth);
+
+    }
+  else
+    {
+      len =
+	strlen ("CONNECT  HTTP/1.0") + strlen (host) + strlen (":") +
+	strlen (port) + 2 + strlen (user_agent) + 2 + strlen (NOCACHE) + 2 +
+	2;
+      my.buffer = xmalloc (len + 1);
+      if (my.buffer == NULL)
+	{
+	  xexit (EXIT_FAILURE);
+	}
+
+      snprintf (my.buffer, len + 1,
+		"CONNECT %s:%s HTTP/1.0\r\n"
+		"%s\r\n" "%s\r\n" "\r\n", host, port, user_agent, NOCACHE);
+    }
+
+  *(my.buffer + len) = '\0';
+
+  /* send */
+  ret = write (sockfd, my.buffer, strlen (my.buffer));
+
+  if (ret != strlen (my.buffer))
+    {
+      fprintf (stderr, "%s: CONVIAHTTP:Fail to write completely\n", progname);
+      if (ret == -1)
+	perror ("CONVIAHTTP:write:Write to myaddr");
+      xfree ((void **) &(my.buffer));
+      return -1;
+    }
+  else
+    xfree ((void **) &(my.buffer));
+
+  /* read estab string */
+  my.buffer = xmalloc (my.myconreplysize);
+  if (my.buffer == NULL)
+    {
+      xexit (EXIT_FAILURE);
+    }
+  memset (my.buffer, 0, my.myconreplysize);
+  p = my.buffer;
+
+  offset = 0;
+
+  while (1)
+    {
+
+      ret = read (sockfd, p, my.myconreplysize - offset - 1);
+      if (ret <= 0)
+	{
+	  break;
+	}
+      /* if(ret < strlen(CONNECT_SUCCESS))return -1; */
+      if ((strstr (my.buffer, CONNECT_SUCCESS0) != NULL)
+	  || (strstr (my.buffer, CONNECT_SUCCESS1) != NULL))
+	{
+	  pxfree ((void **) &(my.buffer));
+	  return 0;
+	}
+      p += ret;
+      offset = p - my.buffer;
+      if ((offset) >= (my.myconreplysize - 1));
+      break;			/* too long */
+    }
+  /* too long or read return 0/-1 */
+  if (debug)
+    fprintf (stderr, "%s: CONVIAHTTP:Reply to CONVIAHTTP is wrong:%s\n",
+	     progname, my.buffer);
+  pxfree ((void **) &(my.buffer));
+  return -1;
+}
+
 /* ***************** inside  thread *********************************/
 /* Connect to testproxy via a HTTP proxy.
  * The HTTP proxy should support CONNECT.
@@ -128,10 +246,11 @@ CONVIAHTTP (int sockfd, struct timeval *start,
 	strlen ((const char *) my.header_auth) + 2 + 2;
 
       thread_mem->request = pxmalloc ((len + 1), thread_mem);
-      if( thread_mem->request == NULL){
-              ret = EXIT_FAILURE;
-              x_pthread_exit((void *)&ret,thread_mem);
-      }
+      if (thread_mem->request == NULL)
+	{
+	  ret = EXIT_FAILURE;
+	  x_pthread_exit ((void *) &ret, thread_mem);
+	}
       snprintf (thread_mem->request, len + 1,
 		"CONNECT %s HTTP/1.0\r\n"
 		"%s\r\n"
@@ -146,10 +265,11 @@ CONVIAHTTP (int sockfd, struct timeval *start,
 	strlen ("CONNECT  HTTP/1.0") + strlen (thread_mem->queue.testproxy) +
 	2 + strlen (user_agent) + 2 + strlen (NOCACHE) + 2 + 2;
       thread_mem->request = pxmalloc ((len + 1), thread_mem);
-      if( thread_mem->request == NULL){
-              ret = EXIT_FAILURE;
-              x_pthread_exit((void *)&ret,thread_mem);
-      }
+      if (thread_mem->request == NULL)
+	{
+	  ret = EXIT_FAILURE;
+	  x_pthread_exit ((void *) &ret, thread_mem);
+	}
 
       snprintf (thread_mem->request, len + 1,
 		"CONNECT %s HTTP/1.0\r\n"
@@ -176,10 +296,11 @@ CONVIAHTTP (int sockfd, struct timeval *start,
 
   /* read estab string */
   thread_mem->reply = pxmalloc (my.myconreplysize, thread_mem);
-  if( thread_mem->reply == NULL){
-          ret = EXIT_FAILURE;
-          x_pthread_exit((void *)&ret,thread_mem);
-  }
+  if (thread_mem->reply == NULL)
+    {
+      ret = EXIT_FAILURE;
+      x_pthread_exit ((void *) &ret, thread_mem);
+    }
   memset (thread_mem->reply, 0, my.myconreplysize);
   p = thread_mem->reply;
 
@@ -206,8 +327,9 @@ CONVIAHTTP (int sockfd, struct timeval *start,
 	break;			/* too long */
     }
   /* too long or read return 0/-1 */
-  fprintf (stderr, "%s: CONVIAHTTP:Reply to CONVIAHTTP is wrong:%s\n",
-	   progname, thread_mem->reply);
+  if (debug)
+    fprintf (stderr, "%s: CONVIAHTTP:Reply to CONVIAHTTP is wrong:%s\n",
+	     progname, thread_mem->reply);
   pxfree ((void **) &(thread_mem->reply));
   return -1;
 }
@@ -237,7 +359,8 @@ PGET (int sockfd, struct timeval *send, struct thread_mem *thread_mem)
     strlen (user_agent) + 2 + strlen (NOCACHE) + 2 + 2;
 
   thread_mem->request = pxmalloc (len + 1, thread_mem);
-  if( thread_mem->request == NULL) x_pthread_exit((void *)&ret,thread_mem);
+  if (thread_mem->request == NULL)
+    x_pthread_exit ((void *) &ret, thread_mem);
 
   snprintf (thread_mem->request, len + 1, "GET %s HTTP/1.0\r\n" "Host: %s\r\n" "%s\r\n%s\r\n" "\r\n", target.target, target.targethost, user_agent, NOCACHE);	/* remove header_auth! */
 
@@ -283,7 +406,8 @@ GET (int sockfd, struct timeval *req, struct thread_mem *thread_mem)
     strlen ("Host: ") + strlen (target.targethost) + 2 +
     strlen (user_agent) + 2 + strlen (NOCACHE) + 2 + 2;
   thread_mem->request = pxmalloc (len + 1, thread_mem);
-  if( thread_mem->request == NULL) x_pthread_exit((void *)&ret,thread_mem);
+  if (thread_mem->request == NULL)
+    x_pthread_exit ((void *) &ret, thread_mem);
 
   snprintf (thread_mem->request, len + 1,
 	    "GET %s HTTP/1.0\r\n"
@@ -335,8 +459,8 @@ PCONGET (int sockfd, struct timeval *start, struct timeval *end,
     strlen ("Host: ") + strlen (target.targethost) + 2 +
     strlen (user_agent) + 2 + strlen (NOCACHE) + 2 + 2;
   thread_mem->request = pxmalloc (len + 1, thread_mem);
-  if( thread_mem == NULL)
-          x_pthread_exit((void *)&ret,thread_mem);
+  if (thread_mem == NULL)
+    x_pthread_exit ((void *) &ret, thread_mem);
   snprintf (thread_mem->request, len + 1, "CONNECT %s:%s HTTP/1.0\r\n" "Host: %s\r\n" "%s\r\n%s\r\n" "\r\n", target.targethost, target.targetport, target.targethost, user_agent, NOCACHE);	/* remove header_auth! */
 
   thread_mem->request[len] = '\0';
@@ -356,7 +480,8 @@ PCONGET (int sockfd, struct timeval *start, struct timeval *end,
 
   /* read estab string */
   thread_mem->reply = pxmalloc (test.testconreplysize, thread_mem);
-  if( thread_mem->reply == NULL) x_pthread_exit((void *)&ret,thread_mem);
+  if (thread_mem->reply == NULL)
+    x_pthread_exit ((void *) &ret, thread_mem);
   memset (thread_mem->reply, 0, test.testconreplysize);
   p = thread_mem->reply;
   while (1)
@@ -369,8 +494,9 @@ PCONGET (int sockfd, struct timeval *start, struct timeval *end,
 
       if (numbytes <= 0)
 	{
-	  fprintf (stderr, "%s: PCONGET:Reply to concon is wrong:%s\n",
-		   progname, thread_mem->reply);
+	  if (debug)
+	    fprintf (stderr, "%s: PCONGET:Reply to concon is wrong:%s\n",
+		     progname, thread_mem->reply);
 	  pxfree ((void **) &(thread_mem->reply));
 	  return -1;
 	}
@@ -382,8 +508,9 @@ PCONGET (int sockfd, struct timeval *start, struct timeval *end,
       if ((p - thread_mem->reply) == test.testconreplysize - 1)
 	{
 	  thread_mem->reply[test.testconreplysize] = '\0';	/* no need ! */
-	  fprintf (stderr, "%s: PCONGET:Reply to concon is wrong:%s\n",
-		   progname, thread_mem->reply);
+	  if (debug)
+	    fprintf (stderr, "%s: PCONGET:Reply to concon is wrong:%s\n",
+		     progname, thread_mem->reply);
 	  pxfree ((void **) &(thread_mem->reply));
 	  return -1;
 	}
