@@ -61,9 +61,10 @@ loop (void *arg)
       read = READAPROXY (&loop_mem);
       if (read == -1)
 	break;			/* end of file */
-      if (read == -2){
-              continue;
-      }
+      if (read == -2)
+	{
+	  continue;
+	}
       /* create socket */
       if ((sockfd = socket (AF_INET, SOCK_STREAM, 0)) == -1)
 	{
@@ -154,13 +155,13 @@ loop (void *arg)
 	      /* verify the result */
 	      if (VERIFY (sockfd, &enter_data, &enter_key, &loop_mem) == 0)
 		{
-		  printf ("Thread %d--Found~~~%s@HTTP delay=%f %f %f\n",
+		  printf ("Thread %d--Found~~~%s@HTTP delay=%.1f %.1f %.1f\n",
 			  *((int *) arg), loop_mem.queue.testproxy,
 			  time_sub (end_estab, start_via),
 			  time_sub (enter_data, start_GET),
 			  time_sub (enter_key, enter_data));
 		  pthread_mutex_lock (&counter_mutex_out);
-		  fprintf (out, "%s@HTTP\t%f %f %f\n",
+		  fprintf (out, "%s@HTTP\t%.1f %.1f %.1f\n",
 			   loop_mem.queue.testproxy,
 			   time_sub (end_estab, start_via),
 			   time_sub (enter_data, start_GET),
@@ -174,18 +175,21 @@ loop (void *arg)
 		goto loop_ex;
 	      if (VERIFY (sockfd, &enter_data, &enter_key, &loop_mem) == 0)
 		{
-		  printf ("Thread %d--Found~~~%s@HTTPC delay=%f %f %f %f\n",
-			  *((int *) arg), loop_mem.queue.testproxy,
-			  time_sub (end_estab, start_via),
-			  time_sub (enter_data, start_GET),
-			  time_sub (enter_key, enter_data), time_sub (end_CON,
-								      start_CON));
-		  fprintf (out, "%s@HTTPC %f %f %f %f\n",
+		  printf
+		    ("Thread %d--Found~~~%s@HTTPC delay=%.1f %.1f %.1f %.1f\n",
+		     *((int *) arg), loop_mem.queue.testproxy,
+		     time_sub (end_estab, start_via), time_sub (enter_data,
+								start_GET),
+		     time_sub (enter_key, enter_data), time_sub (end_CON,
+								 start_CON));
+		  pthread_mutex_lock (&counter_mutex_out);
+		  fprintf (out, "%s@HTTPC %.1f %.1f %.1f %.1f\n",
 			   loop_mem.queue.testproxy, time_sub (end_estab,
 							       start_via),
 			   time_sub (enter_data, start_GET),
 			   time_sub (enter_key, enter_data),
 			   time_sub (end_CON, start_CON));
+		  pthread_mutex_unlock (&counter_mutex_out);
 		}
 	      break;
 	    default:		/* not necessay,should be done in init */
@@ -207,18 +211,21 @@ loop (void *arg)
 		goto loop_ex;
 	      if (VERIFY (sockfd, &enter_data, &enter_key, &loop_mem) == 0)
 		{
-		  printf ("Thread %d--Found~~~%s@SOCKS5C delay=%f %f %f %f\n",
-			  *((int *) arg), loop_mem.queue.testproxy,
-			  time_sub (end_estab, start_via),
-			  time_sub (enter_data, start_GET),
-			  time_sub (enter_key, enter_data), time_sub (end_CON,
-								      start_CON));
-		  fprintf (out, "%s@SOCKS5C %f %f %f %f\n",
+		  printf
+		    ("Thread %d--Found~~~%s@SOCKS5C delay=%.1f %.1f %.1f %.1f\n",
+		     *((int *) arg), loop_mem.queue.testproxy,
+		     time_sub (end_estab, start_via), time_sub (enter_data,
+								start_GET),
+		     time_sub (enter_key, enter_data), time_sub (end_CON,
+								 start_CON));
+		  pthread_mutex_lock (&counter_mutex_out);
+		  fprintf (out, "%s@SOCKS5C %.1f %.1f %.1f %.1f\n",
 			   loop_mem.queue.testproxy, time_sub (end_estab,
 							       start_via),
 			   time_sub (enter_data, start_GET),
 			   time_sub (enter_key, enter_data),
 			   time_sub (end_CON, start_CON));
+		  pthread_mutex_unlock (&counter_mutex_out);
 		}
 	      break;
 	    }
@@ -301,57 +308,62 @@ READAPROXY (struct thread_mem *thread_mem)
 	getaline_r ((char **) &(thread_mem->line), &mlen, in, thread_mem);
       pthread_mutex_unlock (&counter_mutex_in);
 
-      if (read == PROXYKNIFE_THREAD_EXIT) 
-              x_pthread_exit ((void *) &ret, thread_mem);/* memory errors*/
+      if (read == PROXYKNIFE_THREAD_EXIT)
+	x_pthread_exit ((void *) &ret, thread_mem);	/* memory errors */
       if (read == -1)		/* not memory errors */
 	{
 	  if (thread_mem->line)
 	    pxfree ((void **) &(thread_mem->line));
 	  return -1;
 	}			/* read = -1(end of file or stop after errors) or >=1, will not be 0 */
-          /* now file interface end */
+      /* now file interface end */
     }
   else if (proxyknife_in_type == IN_HTTP)
     {
       /* read a line from the buffer */
 
       pthread_mutex_lock (&counter_mutex_in);
-    
-      if( (proxyknife_in_buffer_cur - proxyknife_in_buffer) >=
-                      strlen(proxyknife_in_buffer)){
-              if( thread_mem->line) 
-                      pxfree( (void **)&(thread_mem->line));
-              pthread_mutex_unlock (&counter_mutex_in);
-              return -1;/* beyond buffer */
-      }else{
-      proxyknife_in_buffer_cur = sgetaline (proxyknife_in_buffer_cur,
-                      thread_mem);
-      pthread_mutex_unlock (&counter_mutex_in);
-      if( proxyknife_in_buffer_cur == NULL){ /* memmory error or 
-                                                end of buffer! */
-              if( thread_mem->line){ 
-                      pxfree((void **)&(thread_mem->line));
-              } 
-              x_pthread_exit ((void *) &ret, thread_mem);
-              //return -1; /* or pthread_exit ? */
-      }/* end of buffer */
 
-      read = strlen(thread_mem->line);
-      }
+      if ((proxyknife_in_buffer_cur - proxyknife_in_buffer) >=
+	  strlen (proxyknife_in_buffer))
+	{
+	  if (thread_mem->line)
+	    pxfree ((void **) &(thread_mem->line));
+	  pthread_mutex_unlock (&counter_mutex_in);
+	  return -1;		/* beyond buffer */
+	}
+      else
+	{
+	  proxyknife_in_buffer_cur = sgetaline (proxyknife_in_buffer_cur,
+						thread_mem);
+	  pthread_mutex_unlock (&counter_mutex_in);
+	  if (proxyknife_in_buffer_cur == NULL)
+	    {			/* memmory error or 
+				   end of buffer! */
+	      if (thread_mem->line)
+		{
+		  pxfree ((void **) &(thread_mem->line));
+		}
+	      x_pthread_exit ((void *) &ret, thread_mem);
+	      //return -1; /* or pthread_exit ? */
+	    }			/* end of buffer */
+
+	  read = strlen (thread_mem->line);
+	}
 
 
     }
   else
-    {/* this shuld be done before thread-loop */
+    {				/* this shuld be done before thread-loop */
       fprintf (stderr,
 	       "%s: READAPROXY(Should not happened): proxyknife_in_type = %d is not implemented now!\n",
 	       progname, proxyknife_in_type);
-      xexit(EXIT_FAILURE);
+      xexit (EXIT_FAILURE);
     }
 
   /* truncate trailing '\n' */
   if (*(thread_mem->line + read - 1) == '\n')
-	*(thread_mem->line + read - 1) = '\x0';
+    *(thread_mem->line + read - 1) = '\x0';
 
   /* debug */
   fprintf (stderr, "%s: READAPROXY:Parsing %d bytes: %s\n",
@@ -362,7 +374,7 @@ READAPROXY (struct thread_mem *thread_mem)
   /* need to be mutex and move x_pthread_exit out of it ? */
   if (checkaline (thread_mem) == -1)
     {
-            read = -2;
+      read = -2;
     }
   else
     {
@@ -429,6 +441,11 @@ VERIFY (int sockfd, struct timeval *finddata,
   int numbytes;
   char *p;			/* danger? */
   int t = 0;
+  int ok = 0;
+  char OK10[] = "HTTP/1.0 200 OK\r\n";
+  char OK11[] = "HTTP/1.1 200 OK\r\n";
+  int oklen;
+  oklen = strlen (OK10);
 
   thread_mem->reply = pxmalloc (test.testtagreplysize, thread_mem);
   p = thread_mem->reply;
@@ -444,9 +461,25 @@ VERIFY (int sockfd, struct timeval *finddata,
 	  return -1;
 	}
       t++;
+      p += numbytes;
+
       if (t == 1)
 	gettimeofday (finddata, NULL);
 
+      if ((ok == 0) && (p - thread_mem->reply >= oklen))
+	{
+	  if (strncmp (thread_mem->reply, OK10, oklen) &&
+	      strncmp (thread_mem->reply, OK11, oklen))
+	    {
+	      pxfree ((void **) &(thread_mem->reply));
+	      return -1;	/* error HTTP header */
+	    }
+	  else
+	    {
+	      ok == 1;		/* Found expected response. */
+	    }
+	}
+
       /* printf("RETURN!!!!!!!!!!!!!!!%s",buf); */
 
       gettimeofday (findkey, NULL);	/* save time */
@@ -457,7 +490,6 @@ VERIFY (int sockfd, struct timeval *finddata,
 	  pxfree ((void **) &(thread_mem->reply));
 	  return 0;
 	}
-      p += numbytes;
       if ((p - thread_mem->reply) == (test.testtagreplysize - 1))
 	{
 	  pxfree ((void **) &(thread_mem->reply));
