@@ -31,9 +31,9 @@
 void
 xfree (void **p)
 {
-        assert(p != NULL);
+  assert (p != NULL);
   if (*p != NULL)
-          free (*p);
+    free (*p);
   *p = NULL;
   /* shorten link! */
   /* link->p == NULL */
@@ -47,6 +47,10 @@ mem_init ()
   logfilename = NULL;
   target.key = NULL;
 
+  proxyknife_in = NULL;
+  proxyknife_out = NULL;
+  proxyknife_in_buffer = NULL;
+
   my.myhost = NULL;
   my.myuser = NULL;
   my.mypass = NULL;
@@ -54,6 +58,7 @@ mem_init ()
   my.myuserpass = NULL;
   my.header_auth = NULL;
   my.socks5authreq = NULL;
+  my.buffer = NULL;
 
   target.target = NULL;
   target.targethost = NULL;
@@ -74,6 +79,12 @@ xexit (int status)
     free (user_agent);
   if (target.key)
     free (target.key);
+  if (proxyknife_in)
+    free (proxyknife_in);
+  if (proxyknife_out)
+    free (proxyknife_out);
+  if (proxyknife_in_buffer)
+    free (proxyknife_in_buffer);
   if (my.myhost)
     free (my.myhost);
   if (my.myuser)
@@ -86,6 +97,8 @@ xexit (int status)
     free (my.header_auth);
   if (my.socks5authreq)
     free (my.socks5authreq);
+  if (my.buffer)
+    free (my.buffer);
   if (target.target)
     free (target.target);
   if (target.targethost)
@@ -236,7 +249,7 @@ thread_mem_init (struct thread_mem *thread_mem)
 void
 pxfree (void **p)
 {
-        assert(p!=NULL);
+  assert (p != NULL);
   if (*p)
     free (*p);
   *p = NULL;
