@@ -81,6 +81,12 @@ INIT (int argc, char **argv)
   /* init , used by END() */
   logfd = -1;
 
+  /* debug level */
+  debug = 0;
+
+  /* input mode */
+  proxyknife_in_type = IN_FILE;
+
   mem_init ();
   READCONF (argc, argv);
 
@@ -163,13 +169,14 @@ INIT (int argc, char **argv)
   else if (proxyknife_in_type == IN_HTTP)
     {
       /* store all proxylist into proxyknife_in_buffer */
-        fetchproxylist(proxyknife_in); 
-        proxyknife_in_buffer_cur = proxyknife_in_buffer;
+      fetchproxylist (proxyknife_in);
+      proxyknife_in_buffer_cur = proxyknife_in_buffer;
     }
   else
     {
       fprintf (stderr, __FILE__ " INIT:proxyknife_in_type unknown: %d !\n",
 	       proxyknife_in_type);
+      xfree ((void **) &proxyknife_in);
       xexit (EXIT_FAILURE);
     }
 
@@ -201,8 +208,11 @@ INIT (int argc, char **argv)
 	    }
 	  else
 	    {
-	      fprintf (stderr, "Dup stderr to log file %d (%s)now!\n", logfd,
-		       logfilename);
+	      if (debug)
+		{
+		  printf ("Dup stderr to log file %d (%s)now!\n", logfd,
+			  logfilename);
+		}
 	      /* close(2) if necessary) */
 	      if (dup2 (logfd, 2) == -1)
 		{
@@ -234,7 +244,11 @@ THREAD ()
 
   /* Ignore SIGPIPE. */
   /* Write() will return with EPIPE error when socket is closed. */
-  signal (SIGPIPE, SIG_IGN);
+  if (SIG_ERR == signal (SIGPIPE, SIG_IGN))
+    {
+      fprintf (stderr, "Signal redefine failed\n");
+    }
+
 
   /* Initialize and set thread detached attribute */
   pthread_attr_init (&attr);
@@ -263,7 +277,8 @@ THREAD ()
     {
       if (pthread_join (tid[i], &status) == 0)
 	{
-	  /*printf("join thread %d\n",i,*(int *)status); */
+	  if (debug)
+	    printf ("join thread %d\n", i, *(int *) status);
 	}
       else
 	{
@@ -281,7 +296,8 @@ THREAD ()
 void
 END ()
 {
-  if(in!=NULL)fclose (in);
+  if (in != NULL)
+    fclose (in);
   fclose (out);
   if (logfd != -1)
     close (logfd);
