@@ -86,12 +86,21 @@ struct testqueue
 /* Request method. */
 #define HTTP_GET 0
 #define HTTP_CONNECT 1
+
 #define SOCKS5_CONNECT 2
 #define SOCKS5_UDP 3 
 #define SOCKS5_BIND 4
+
 #define SOCKS4_CONNECT 5
 #define SOCSK4_BIND 6
 
+#define SOCKS4A_CONNECT 7
+#define SOCKS4A_BIND 8
+
+#define HTTP_CONNECT_AUTH  11
+#define SOCKS5_CONNECT_AUTH 12
+
+
 /* input interface */
 #define IN_FILE 0
 #define IN_HTTP 1 
@@ -101,14 +110,12 @@ struct test
 {
 /*now only  HTTP_GET ,HTTP_CONNECT is supported*/
   int httptestmethod, socks5testmethod,socks4testmethod;
-  int testconreplysize;
-  int testtagreplysize;
+  int testconreplysize;/* Including trailing '\0' */
+  int testtagreplysize;/* Including trailing '\0' */
 };
 struct test test;
-#define DIRECT 5 
-#define HTTP_CONNECT_AUTH 3
-#define SOCKS5_CONNECT_AUTH 4
 
+#define DIRECT 21 
 /* The myproxy struct. */
 /* now only HTTP_CONNECT,HTTP_CONNECT_AUTH is permitted for mytype */
 struct my
@@ -126,6 +133,7 @@ struct my
   char *myuser;
   char *mypass;
   char *socks5authreq;
+  char *buffer; /* reply  or request via myproxy */
 };
 struct my my;
 
@@ -139,7 +147,7 @@ struct target
 /* part of  HTTP CONNECT request to testproxy,global if need */
   char *targethost, *targetport, *targetpath;
   struct sockaddr_in targetaddr;
-#define KEY "2005 Google"
+#define KEY "2006 Google"
   char *key;			/* global */
 };
 struct target target;
@@ -158,6 +166,8 @@ int threads;
 /* return value for wrapper functions */
 #define PROXYKNIFE_THREAD_EXIT -3
 
+/* debug */
+int debug;
 /* log filename */
 char *logfilename;
 #define LOGSTDERR "."
@@ -240,6 +250,7 @@ char * sgetaline (char *s,struct thread_mem *thread_mem);
 
 /* http.c */
 void http_build_auth (void);
+int CONVIAHTTP_MAIN(int sockfd,char *host, char *port);
 int CONVIAHTTP (int sockfd, struct timeval *start,
 		struct timeval *end, struct thread_mem *thread_mem);
 int PGET (int sockfd, struct timeval *send, struct thread_mem *thread_mem);
@@ -252,9 +263,13 @@ void s5_build_auth (void);
 int s5_nego_free (int sockfd);
 int s5_nego_auth (int sockfd);
 int s5con (int sockfd, struct sockaddr *serv);
+int CONVIASOCKS5_MAIN (int sockfd, struct sockaddr *addr);
+int CONVIASOCKS5 (int sockfd, struct timeval *start,
+	      struct timeval *end, struct thread_mem *thread_mem);
 int S5PCONGET (int sockfd, struct timeval *start_CON, struct timeval *end_CON,
 	       struct timeval *start_GET, struct thread_mem *thread_mem);
 
+
 /* socks4.c */
 int s4con (int sockfd, struct sockaddr *serv);
 int S4PCONGET (int sockfd, struct timeval *start_CON, struct timeval *end_CON,
